@@ -53,16 +53,16 @@ ImageViewer::ImageViewer(QWidget *parent) : QGraphicsView(parent), d(new Private
     setScene(d->scene);
 
     // create context menu
-    d->zoomInAction = new QAction(QIcon::fromTheme(QLatin1String("zoom-in")), i18n("Zoom In"), this);
+    d->zoomInAction = new QAction(QIcon::fromTheme(QStringLiteral("zoom-in")), i18n("Zoom In"), this);
     connect(d->zoomInAction, &QAction::triggered, this, &ImageViewer::zoomIn);
 
-    d->zoomOutAction = new QAction(QIcon::fromTheme(QLatin1String("zoom-out")), i18n("Zoom Out"), this);
+    d->zoomOutAction = new QAction(QIcon::fromTheme(QStringLiteral("zoom-out")), i18n("Zoom Out"), this);
     connect(d->zoomOutAction, &QAction::triggered, this, &ImageViewer::zoomOut);
 
-    d->zoom100Action = new QAction(QIcon::fromTheme(QLatin1String("zoom-fit-best")), i18n("Zoom to Actual size"), this);
+    d->zoom100Action = new QAction(QIcon::fromTheme(QStringLiteral("zoom-fit-best")), i18n("Zoom to Actual size"), this);
     connect(d->zoom100Action, &QAction::triggered, this, &ImageViewer::zoomActualSize);
 
-    d->zoom2FitAction = new QAction(QIcon::fromTheme(QLatin1String("document-preview")), i18n("Zoom to Fit"), this);
+    d->zoom2FitAction = new QAction(QIcon::fromTheme(QStringLiteral("document-preview")), i18n("Zoom to Fit"), this);
     connect(d->zoom2FitAction, &QAction::triggered, this, &ImageViewer::zoom2Fit);
 
     addAction(d->zoomInAction);
